@@ -117,13 +117,14 @@ process_statistic_formatting.tplyr_riskdiff <- function(x, ...) {
                                        by=c(match_exact(c(by, cols, head(target_var, -1))),  'summary_var'))
 
     if (length(cols) > 0) {
+
       # If only one comparison was made, the columns won't prefix with the transposed variable name
       # So trick it by introducing a column I can drop later. Not great, but functional
       formatted_statistic_data['rdiffx'] <- ''
 
       # Pivot by column
       formatted_statistic_data <- formatted_statistic_data %>%
-        pivot_wider(id_cols=c(match_exact(c(by, cols, head(target_var, -1))),  'summary_var'),
+        pivot_wider(id_cols=c(match_exact(c(by, head(target_var, -1))),  'summary_var'),
                     names_from = match_exact(cols),
                     names_sep = "_",
                     values_from=starts_with('rdiff'))
